pub struct DapClient { /* private fields */ }Expand description
A simple DAP protocol client that communicates over TCP.
Implementations
Sourceimpl DapClient
impl DapClient
Sourcepub fn connect(addr: &str) -> Result<DapClient, String>
pub fn connect(addr: &str) -> Result<DapClient, String>
Connect to a DAP server at the given address (e.g. “127.0.0.1:4711”).
Sourcepub fn handshake(&mut self) -> Result<DapUiState, String>
pub fn handshake(&mut self) -> Result<DapUiState, String>
Perform the DAP handshake: Initialize + Launch + ConfigurationDone. Waits for the initial Stopped(entry) event and returns the server-pushed UI state snapshot.
Sourcepub fn step_in(&mut self) -> Result<DapStopReason, String>
pub fn step_in(&mut self) -> Result<DapStopReason, String>
Send a StepIn command and wait for a Stopped/Terminated event.
Sourcepub fn step_over(&mut self) -> Result<DapStopReason, String>
pub fn step_over(&mut self) -> Result<DapStopReason, String>
Send a Next (step over) command and wait for a Stopped/Terminated event.
Sourcepub fn step_out(&mut self) -> Result<DapStopReason, String>
pub fn step_out(&mut self) -> Result<DapStopReason, String>
Send a StepOut command and wait for a Stopped/Terminated event.
Sourcepub fn continue_(&mut self) -> Result<DapStopReason, String>
pub fn continue_(&mut self) -> Result<DapStopReason, String>
Send a Continue command and wait for a Stopped/Terminated event.
Sourcepub fn stack_trace(&mut self) -> Result<Vec<StackFrame>, String>
pub fn stack_trace(&mut self) -> Result<Vec<StackFrame>, String>
Query the current stack trace.
Sourcepub fn variables(
&mut self,
variables_reference: i64,
) -> Result<Vec<Variable>, String>
pub fn variables( &mut self, variables_reference: i64, ) -> Result<Vec<Variable>, String>
Query variables for a given scope reference.
Sourcepub fn evaluate(&mut self, expression: &str) -> Result<String, String>
pub fn evaluate(&mut self, expression: &str) -> Result<String, String>
Evaluate a custom expression (e.g. “__miden_state”).
Sourcepub fn read_memory(&mut self, expr: &ReadMemoryExpr) -> Result<String, String>
pub fn read_memory(&mut self, expr: &ReadMemoryExpr) -> Result<String, String>
Read memory from the remote debuggee via the DAP server.
Sourcepub fn set_breakpoints(
&mut self,
path: &str,
lines: &[i64],
) -> Result<(), String>
pub fn set_breakpoints( &mut self, path: &str, lines: &[i64], ) -> Result<(), String>
Set breakpoints for a source file.
Sourcepub fn set_function_breakpoints(
&mut self,
names: &[String],
) -> Result<(), String>
pub fn set_function_breakpoints( &mut self, names: &[String], ) -> Result<(), String>
Set function breakpoints (matched as glob patterns against context names and file paths).
Sourcepub fn restart(&mut self) -> Result<DapStopReason, String>
pub fn restart(&mut self) -> Result<DapStopReason, String>
Send a Restart command and wait for a Stopped event (program restarted at entry).
The server resets the processor to the beginning of the program with the same
inputs and re-emits miden/uiState + Stopped(entry).
Sourcepub fn restart_phase2(&mut self) -> Result<DapStopReason, String>
pub fn restart_phase2(&mut self) -> Result<DapStopReason, String>
Send a Phase 2 restart command (with arguments) and wait for the server’s response.
The server will respond with Terminated(restart=true) and shut down so the caller
can recompile and reconnect.
Sourcepub fn connect_with_retry(
addr: &str,
timeout: Duration,
) -> Result<DapClient, String>
pub fn connect_with_retry( addr: &str, timeout: Duration, ) -> Result<DapClient, String>
Connect to a DAP server with exponential backoff, for Phase 2 reconnection.
Polls with delays from 50ms up to 1s, timing out after timeout.
Sourcepub fn disconnect(&mut self) -> Result<(), String>
pub fn disconnect(&mut self) -> Result<(), String>
Disconnect from the DAP server.