pub struct DebugLogger(/* private fields */);Implementations
Sourceimpl DebugLogger
impl DebugLogger
Sourcepub fn install_with_max_level(
inner: Box<dyn Log>,
max_level: LevelFilter,
) -> Result<(), SetLoggerError>
pub fn install_with_max_level( inner: Box<dyn Log>, max_level: LevelFilter, ) -> Result<(), SetLoggerError>
Returns an error if the global logger was already initialized.
pub fn get() -> &'static Self
pub fn take_captured(&self) -> VecDeque<LogEntry>
Sourcepub fn count_matching<F>(&self, predicate: F) -> usize
pub fn count_matching<F>(&self, predicate: F) -> usize
Counts the number of log entries in the ring buffer which match predicate
Sourcepub fn contains_matching<F>(&self, predicate: F) -> bool
pub fn contains_matching<F>(&self, predicate: F) -> bool
Returns true if any entry in the ring buffer matches predicate
Sourcepub fn select_matching<F>(&self, predicate: F) -> Vec<LogEntry>
pub fn select_matching<F>(&self, predicate: F) -> Vec<LogEntry>
Clones all of the log entries in the buffer which match predicate.
pub fn clone_captured(&self) -> VecDeque<LogEntry>
Sourcepub fn init_for_tests() -> Result<(), SetLoggerError>
pub fn init_for_tests() -> Result<(), SetLoggerError>
Returns an error if the global logger was already initialized.