pub struct ScriptDebugger { /* private fields */ }Expand description
Stable facade used by debugger scripting integrations.
Implementations
Sourceimpl ScriptDebugger
impl ScriptDebugger
Sourcepub fn new(config: Box<DebuggerConfig>) -> Result<Self, Report>
pub fn new(config: Box<DebuggerConfig>) -> Result<Self, Report>
Create a script debugger from the same configuration used by the REPL.
Sourcepub fn from_config(config: Box<DebuggerConfig>) -> Result<Self, Report>
pub fn from_config(config: Box<DebuggerConfig>) -> Result<Self, Report>
Create a script debugger from a debugger configuration.
Sourcepub fn from_masm_source(source: &str, args: Vec<Felt>) -> Result<Self, Report>
pub fn from_masm_source(source: &str, args: Vec<Felt>) -> Result<Self, Report>
Create a script debugger from inline MASM source.
This is useful for tests and small programmatic debugging harnesses.
Sourcepub fn handle_command(&self, command: &str) -> Result<String, String>
pub fn handle_command(&self, command: &str) -> Result<String, String>
Execute a debugger command and capture its textual output.
Sourcepub fn terminated(&self) -> bool
pub fn terminated(&self) -> bool
Whether the debuggee has terminated.
Sourcepub fn source_path_prefixes(&self) -> Vec<String>
pub fn source_path_prefixes(&self) -> Vec<String>
Source path prefix mappings currently configured for this debugger.
Sourcepub fn frame(&self) -> ScriptFrame
pub fn frame(&self) -> ScriptFrame
Current frame snapshot.
Sourcepub fn frame_with_variables(&self, show_all: bool) -> ScriptFrame
pub fn frame_with_variables(&self, show_all: bool) -> ScriptFrame
Current frame snapshot with either source-visible or all debug variables.
Sourcepub fn execution_context(&self) -> ScriptExecutionContext
pub fn execution_context(&self) -> ScriptExecutionContext
Current execution context snapshot.
Sourcepub fn breakpoints(&self) -> Vec<ScriptBreakpoint>
pub fn breakpoints(&self) -> Vec<ScriptBreakpoint>
Current user-visible breakpoints.
Sourcepub fn hit_breakpoints(&self) -> Vec<ScriptBreakpoint>
pub fn hit_breakpoints(&self) -> Vec<ScriptBreakpoint>
Breakpoints hit at the current stop.
Sourcepub fn clear_hit_breakpoints(&self)
pub fn clear_hit_breakpoints(&self)
Clear the current hit-breakpoint list.
Sourcepub fn set_breakpoint(&self, spec: &str) -> Result<ScriptBreakpoint, String>
pub fn set_breakpoint(&self, spec: &str) -> Result<ScriptBreakpoint, String>
Set a breakpoint from the normal debugger breakpoint grammar.
Sourcepub fn delete_breakpoint(&self, id: Option<u8>) -> Result<(), String>
pub fn delete_breakpoint(&self, id: Option<u8>) -> Result<(), String>
Delete one breakpoint by id, or all user breakpoints if id is None.
Sourcepub fn read_memory(&self, expression: &str) -> Result<String, String>
pub fn read_memory(&self, expression: &str) -> Result<String, String>
Read memory using the debugger memory expression grammar.
Sourcepub fn continue_(&self) -> Result<String, String>
pub fn continue_(&self) -> Result<String, String>
Continue execution until the next breakpoint or termination.