pub struct DebugExecutor {Show 17 fields
pub processor: FastProcessor,
pub host: DebuggerHost<dyn SourceManager>,
pub resume_ctx: Option<ResumeContext>,
pub current_stack: Vec<Felt>,
pub current_op: Option<Operation>,
pub current_asmop: Option<AssemblyOp>,
pub stack_outputs: StackOutputs,
pub contexts: BTreeSet<ContextId>,
pub root_context: ContextId,
pub current_context: ContextId,
pub callstack: CallStack,
pub current_proc: Option<Rc<str>>,
pub debug_vars: DebugVarTracker,
pub last_debug_var_count: usize,
pub recent: VecDeque<Operation>,
pub cycle: usize,
pub stopped: bool,
}Expand description
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
This is used by the debugger to execute programs, and provide all of the functionality made available by the TUI.
Fields
processor: FastProcessorThe underlying FastProcessor being driven
host: DebuggerHost<dyn SourceManager>The host providing debugging callbacks
resume_ctx: Option<ResumeContext>The resume context for the next step (None if program has finished)
current_stack: Vec<Felt>The current operand stack state
current_op: Option<Operation>The operation that was just executed
current_asmop: Option<AssemblyOp>The assembly-level operation info for the current op
stack_outputs: StackOutputsThe final outcome of the program being executed
contexts: BTreeSet<ContextId>The set of contexts allocated during execution so far
root_context: ContextIdThe root context
current_context: ContextIdThe current context at cycle
callstack: CallStackThe current call stack
current_proc: Option<Rc<str>>The most recent live procedure name observed from assembly operation metadata.
debug_vars: DebugVarTrackerDebug variable tracker for source-level variable inspection
last_debug_var_count: usizeNumber of debug variable location records observed during the most recent step.
recent: VecDeque<Operation>A sliding window of the last 5 operations successfully executed by the VM
cycle: usizeThe current clock cycle
stopped: boolWhether or not execution has terminated
Implementations
Sourceimpl DebugExecutor
impl DebugExecutor
Sourcepub fn procedure_has_debug_vars(&self, procedure: &str) -> bool
pub fn procedure_has_debug_vars(&self, procedure: &str) -> bool
Returns true if the current program forest has debug-variable locations associated with
procedure.
pub fn register_trace_monitor_for( &mut self, monitor: TraceMonitor, event: TraceEvent, )
Sourcepub fn step(&mut self) -> Result<Option<CallFrame>, ExecutionError>
pub fn step(&mut self) -> Result<Option<CallFrame>, ExecutionError>
Advance the program state by one cycle.
If the program has already reached its termination state, it returns the same result as the previous time it was called.
Returns the call frame exited this cycle, if any
Sourcepub fn step_until(
&mut self,
breakpoint: BreakpointType,
trace_monitor: Option<TraceMonitor>,
source_manager: &dyn SourceManager,
) -> Result<(), ExecutionError>
pub fn step_until( &mut self, breakpoint: BreakpointType, trace_monitor: Option<TraceMonitor>, source_manager: &dyn SourceManager, ) -> Result<(), ExecutionError>
Advance the program state until breakpoint is hit.
If the program has already reached its termination state, it returns the same result as the previous time it was called.
Sourcepub fn into_execution_trace(self) -> ExecutionTrace
pub fn into_execution_trace(self) -> ExecutionTrace
Consume the DebugExecutor, converting it into an ExecutionTrace at the current cycle.