DebuggerHost

Struct DebuggerHost 

pub struct DebuggerHost<S: SourceManager> { /* private fields */ }
This is an implementation of BaseHost which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.

Implementations

Source

impl<S> DebuggerHost<S>
where S: SourceManager,

pub fn new(_adv_provider: AdviceProvider, source_manager: S) -> Self

Construct a new instance of DebuggerHost with the given advice provider.

pub fn register_trace_handler<F>(&mut self, event: TraceEvent, callback: F)
where F: FnMut(RowIndex, TraceEvent) + 'static,

Register a trace handler for event

pub fn register_assert_failed_tracer<F>(&mut self, callback: F)
where F: FnMut(RowIndex, TraceEvent) + 'static,

Register a handler to be called when an assertion in the VM fails

pub fn load_mast_forest(&mut self, forest: Arc<MastForest>)

Load forest into the MAST store for this host