pub struct Executor { /* private fields */ }Expand description
The Executor is responsible for executing a program with the Miden VM.
It is used by either converting it into a DebugExecutor, and using that to manage execution step-by-step, such as is done by the debugger; or by running the program to completion and obtaining an ExecutionTrace, which can be used to introspect the final program state.
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn new(args: Vec<Felt>) -> Self
pub fn new(args: Vec<Felt>) -> Self
Construct an executor with the given arguments on the operand stack
Sourcepub fn from_config(config: ExecutionConfig) -> Self
pub fn from_config(config: ExecutionConfig) -> Self
Construct an executor from the given configuration
NOTE: The execution options for tracing/debugging will be set to true for you
Sourcepub fn for_package<I>(package: &Package, args: I) -> Result<Self, Report>where
I: IntoIterator<Item = Felt>,
pub fn for_package<I>(package: &Package, args: I) -> Result<Self, Report>where
I: IntoIterator<Item = Felt>,
Construct the executor with the given inputs and adds dependencies from the given package
Sourcepub fn with_dependencies<'a>(
&mut self,
dependencies: impl Iterator<Item = &'a Dependency>,
) -> Result<&mut Self, Report>
pub fn with_dependencies<'a>( &mut self, dependencies: impl Iterator<Item = &'a Dependency>, ) -> Result<&mut Self, Report>
Adds dependencies to the executor
Sourcepub fn with_advice_inputs(&mut self, advice: AdviceInputs) -> &mut Self
pub fn with_advice_inputs(&mut self, advice: AdviceInputs) -> &mut Self
Set the contents of memory for the shadow stack frame of the entrypoint
Sourcepub fn with_library(&mut self, lib: Arc<Library>) -> &mut Self
pub fn with_library(&mut self, lib: Arc<Library>) -> &mut Self
Add a Library to the execution context
Sourcepub fn into_debug(
self,
program: &Program,
source_manager: Arc<dyn SourceManager>,
) -> DebugExecutor ⓘ
pub fn into_debug( self, program: &Program, source_manager: Arc<dyn SourceManager>, ) -> DebugExecutor ⓘ
Convert this Executor into a DebugExecutor, which captures much more information about the program being executed, and must be stepped manually.
Sourcepub fn capture_trace(
self,
program: &Program,
source_manager: Arc<dyn SourceManager>,
) -> ExecutionTrace
pub fn capture_trace( self, program: &Program, source_manager: Arc<dyn SourceManager>, ) -> ExecutionTrace
Execute the given program until termination, producing a trace
Sourcepub fn execute(
self,
program: &Program,
source_manager: Arc<dyn SourceManager>,
) -> ExecutionTrace
pub fn execute( self, program: &Program, source_manager: Arc<dyn SourceManager>, ) -> ExecutionTrace
Execute the given program, producing a trace
Sourcepub fn execute_into<T>(
self,
program: &Program,
source_manager: Arc<dyn SourceManager>,
) -> Twhere
T: FromMidenRepr + PartialEq,
pub fn execute_into<T>(
self,
program: &Program,
source_manager: Arc<dyn SourceManager>,
) -> Twhere
T: FromMidenRepr + PartialEq,
Execute a program, parsing the operand stack outputs as a value of type T
pub fn dependency_resolver_mut(&mut self) -> &mut MemDependencyResolverByDigest