Skip to main content Crate miden_debug Copy item path Source pub use miden_debug_engine::debug_types ;pub use miden_debug_engine::processor ;debug event This module contains the set of compiler-emitted event codes, and their explanations events exec felt flamegraph logger script Script-facing debugger facade. Breakpoint CallFrame CallStack CurrentFrame DapClient A simple DAP protocol client that communicates over TCP. DapConfig Configuration for the DAP debug server. DapExecutor A [ProgramExecutor] that starts a DAP TCP server and steps through the program
interactively. DapUiFrame A single remote frame within a bundled UI-state snapshot. DapUiState A bundled snapshot of the remote state needed by the TUI. DebugExecutor A special version of crate::Executor which provides finer-grained control over execution,
and captures a ton of information about the program being executed, so as to make it possible
to introspect everything about the program and the state of the VM at a given cycle. DebugVarSnapshot A snapshot of a debug variable at a specific clock cycle. DebugVarTracker Tracks debug variable snapshots, mapping variable names to their most recent location info. DebuggerConfig Run a compiled Miden package with the Miden VM DebuggerHost This is an implementation of [Host] which is essentially miden_processor::DefaultHost ,
but extended with additional functionality for debugging, in particular it manages trace
events that record the entry or exit of a procedure call frame. DiagnosticExecutor A [ProgramExecutor] that wraps FastProcessor with diagnostic capabilities. EventMutationRecorder A shared, cloneable log of the advice mutations produced by event handlers. ExecutionConfig ExecutionTrace An ExecutionTrace represents a final state of a program that was executed. Executor The Executor is responsible for executing a program with the Miden VM. Felt Wrapper around miden_processor::Felt that implements useful traits that are not implemented
for that type. HybridPackageRegistry The in-memory package registry used by the compiler InlineCallFrame LinkLibrary A library requested by the user to be linked against during compilation LogicalStackFrame MastForestRecorder A shared, cloneable log of the MAST forests a host resolved during execution. NativePtr This represents a descriptor for a pointer translated from the IR into a form suitable for
referencing data in Miden’s linear memory. RawFelt A Felt backed by Plonky3’s Goldilocks field element. ReadMemoryExpr ReplaySnapshot Everything needed to replay a recorded execution in the debugger. ReplaySnapshotRecorder Shared status handle for a configured replay snapshot write. ReplaySnapshotWrite Successful replay snapshot write metadata. ReplaySnapshotWriteError Error metadata for a failed replay snapshot write. ResolvedLocation StackTrace State StepInfo TypedProcedure Typed ABI metadata for a package entrypoint. BreakpointType ColorChoice ColorChoice represents the color preferences of an end user. ControlFlowOp DapStopReason The reason the debuggee stopped after a step/continue command. DebugMode Whether the debugger is debugging a plain program or a transaction. Event A typed wrapper around the raw trace events known to the compiler FormatType InputFile LogicalFrameKind MemoryMode OpDetail OperationMatcher ReplaySnapshotError Error reading a ReplaySnapshot from a file. SCOPE_MEMORY SCOPE_STACK Variables reference IDs for scopes (must match the DAP server). DebugQuery FromMidenRepr ToMidenRepr bytes_to_words Convert a byte array to an equivalent vector of words clone_advice_mutation Clone a single AdviceMutation . clone_advice_mutations Clone a batch of AdviceMutation s. See clone_advice_mutation . format_value Resolves and decodes the package debug type represented by ty. inline_frames_for_operation Resolves the inline frames active for an operation. is_internal_source_uri Returns true for source paths emitted by compiler/runtime internals rather than user code. push_wasm_ty_to_operand_stack Converts value to its corresponding Wasm ABI type and pushes it to the stack. read_advice_mutation Deserialize a single AdviceMutation from source. read_event_log Deserialize a recorded event log from source. resolve_location_from_filesystem Resolve a source location directly from the filesystem, returning the resolved path and line. resolve_source_file_for_location Resolve a source file for location. resolve_source_path Resolve a source URI to an existing local filesystem path. resolve_typed_variable_values Resolve a typed debug variable into the canonical ABI felts consumed by the typed decoder. resolve_variable_value Resolve a debug variable’s value given its location and the current VM state. resolve_variable_values Resolve one or more consecutive felts for a debug variable. run run_commands Run a script of debugger commands non-interactively, then return. run_dap_server Start a DAP server for a local Miden program. run_repl Run the REPL debugger with the given configuration. run_repl_with_log_level Run the REPL debugger with the given configuration and log level filter. run_replay_and_log_level Replay a recorded execution snapshot in the TUI debugger. run_with_log_level run_with_state Launch the TUI debugger with a pre-built State . run_with_state_and_log_level Launch the TUI debugger with a pre-built State and log level filter. snapshot_transient_debug_values Snapshot transient debug locations at the decorator point. write_advice_mutation Serialize a single AdviceMutation into target. write_event_log Serialize a recorded event log (one entry per on_event invocation) into target.