Crate miden_debug

Crate miden_debug 

Modules

debug
exec
felt
logger

Structs

Breakpoint
CallFrame
CallStack
CurrentFrame
DapClient
A simple DAP protocol client that communicates over TCP.
DapConfig
Configuration for the DAP debug server.
DapExecutor
A ProgramExecutor that starts a DAP TCP server and steps through the program interactively.
DapUiFrame
A single remote frame within a bundled UI-state snapshot.
DapUiState
A bundled snapshot of the remote state needed by the TUI.
DebugExecutor
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
DebugVarSnapshot
A snapshot of a debug variable at a specific clock cycle.
DebugVarTracker
Tracks debug variable snapshots, mapping variable names to their most recent location info.
DebuggerConfig
Run a compiled Miden program with the Miden VM
DebuggerHost
This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
DiagnosticExecutor
A ProgramExecutor that wraps FastProcessor with diagnostic capabilities.
ExecutionConfig
ExecutionTrace
An ExecutionTrace represents a final state of a program that was executed.
Executor
The Executor is responsible for executing a program with the Miden VM.
Felt
Wrapper around miden_processor::Felt that implements useful traits that are not implemented for that type.
LinkLibrary
A library requested by the user to be linked against during compilation
NativePtr
This represents a descriptor for a pointer translated from the IR into a form suitable for referencing data in Miden’s linear memory.
ReadMemoryExpr
ResolvedLocation
StackTrace
State
StepInfo
TraceMonitor
Can be used with DebugExecutor::step_until to break on trace events

Enums

BreakpointType
ColorChoice
ColorChoice represents the color preferences of an end user.
ControlFlowOp
DapStopReason
The reason the debuggee stopped after a step/continue command.
DebugMode
Whether the debugger is debugging a plain program or a transaction.
FormatType
InputFile
LibraryKind
The types of libraries that can be linked against during compilation
MemoryMode
OpDetail
TraceEvent
A typed wrapper around the raw trace events known to the compiler

Constants

SCOPE_MEMORY
SCOPE_STACK
Variables reference IDs for scopes (must match the DAP server).
TRACE_PRINT_LN
This event is emitted via trace, and indicates that a line should be printed.

Traits

FromMidenRepr
ProgramExecutor
A transaction-scoped program executor used by TransactionExecutor.
ToMidenRepr

Functions

bytes_to_words
Convert a byte array to an equivalent vector of words
push_wasm_ty_to_operand_stack
Converts value to its corresponding Wasm ABI type and pushes it to the stack.
resolve_variable_value
Resolve a debug variable’s value given its location and the current VM state.
run
run_with_log_level
run_with_state
Launch the TUI debugger with a pre-built State.
run_with_state_and_log_level
Launch the TUI debugger with a pre-built State and log level filter.

Type Aliases

TraceHandler
A callback to be executed when a TraceEvent occurs