Modules
Structs
- Breakpoint
- Call
Frame - Call
Stack - Current
Frame - DapClient
- A simple DAP protocol client that communicates over TCP.
- DapConfig
- Configuration for the DAP debug server.
- DapExecutor
- A
ProgramExecutorthat starts a DAP TCP server and steps through the program interactively. - DapUi
Frame - A single remote frame within a bundled UI-state snapshot.
- DapUi
State - A bundled snapshot of the remote state needed by the TUI.
- Debug
Executor - A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
- Debugger
Config - Run a compiled Miden program with the Miden VM
- Debugger
Host - This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
- Diagnostic
Executor - A
ProgramExecutorthat wrapsFastProcessorwith diagnostic capabilities. - Execution
Config - Execution
Trace - An ExecutionTrace represents a final state of a program that was executed.
- Executor
- The Executor is responsible for executing a program with the Miden VM.
- Felt
- Wrapper around
miden_processor::Feltthat implements useful traits that are not implemented for that type. - Link
Library - A library requested by the user to be linked against during compilation
- Native
Ptr - This represents a descriptor for a pointer translated from the IR into a form suitable for referencing data in Miden’s linear memory.
- Read
Memory Expr - Resolved
Location - Stack
Trace - State
- Step
Info
Enums
- Breakpoint
Type - Color
Choice - ColorChoice represents the color preferences of an end user.
- Control
Flow Op - DapStop
Reason - The reason the debuggee stopped after a step/continue command.
- Debug
Mode - Whether the debugger is debugging a plain program or a transaction.
- Format
Type - Input
File - Library
Kind - The types of libraries that can be linked against during compilation
- Memory
Mode - OpDetail
- Trace
Event - A typed wrapper around the raw trace events known to the compiler
Constants
- SCOPE_
MEMORY - SCOPE_
STACK - Variables reference IDs for scopes (must match the DAP server).
Traits
- From
Miden Repr - Program
Executor - A transaction-scoped program executor used by
TransactionExecutor. - ToMiden
Repr
Functions
- bytes_
to_ words - Convert a byte array to an equivalent vector of words
- push_
wasm_ ty_ to_ operand_ stack - Converts
valueto its corresponding Wasm ABI type and pushes it to the stack. - run
- run_
with_ state - Launch the TUI debugger with a pre-built State.
Type Aliases
- Trace
Handler - A callback to be executed when a TraceEvent occurs at a given clock cycle