Crate miden_debug

Crate miden_debug 

Structs

Breakpoint
CallFrame
CallStack
CurrentFrame
DebugExecutor
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
DebuggerHost
This is an implementation of BaseHost which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
ExecutionConfig
ExecutionTrace
An ExecutionTrace represents a final state of a program that was executed.
Executor
The Executor is responsible for executing a program with the Miden VM.
Felt
Wrapper around miden_processor::Felt that implements useful traits that are not implemented for that type.
LinkLibrary
A library requested by the user to be linked against during compilation
MemoryChiplet
NativePtr
This represents a descriptor for a pointer translated from the IR into a form suitable for referencing data in Miden’s linear memory.
ReadMemoryExpr
ResolvedLocation
StackTrace

Enums

BreakpointType
FormatType
LibraryKind
The types of libraries that can be linked against during compilation
MemoryMode
OpDetail
TraceEvent
A typed wrapper around the raw trace events known to the compiler

Traits

FromMidenRepr
ToMidenRepr

Functions

bytes_to_words
Convert a byte array to an equivalent vector of words

Type Aliases

TraceHandler
A callback to be executed when a TraceEvent occurs at a given clock cycle