Module exec

Module exec 

Structs

DapClient
A simple DAP protocol client that communicates over TCP.
DapConfig
Configuration for the DAP debug server.
DapExecutor
A ProgramExecutor that starts a DAP TCP server and steps through the program interactively.
DapUiFrame
A single remote frame within a bundled UI-state snapshot.
DapUiState
A bundled snapshot of the remote state needed by the TUI.
DebugExecutor
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
DebuggerHost
This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
DiagnosticExecutor
A ProgramExecutor that wraps FastProcessor with diagnostic capabilities.
ExecutionConfig
ExecutionTrace
An ExecutionTrace represents a final state of a program that was executed.
Executor
The Executor is responsible for executing a program with the Miden VM.
TraceMonitor
Can be used with DebugExecutor::step_until to break on trace events

Enums

DapStopReason
The reason the debuggee stopped after a step/continue command.
TraceEvent
A typed wrapper around the raw trace events known to the compiler

Constants

SCOPE_MEMORY
SCOPE_STACK
Variables reference IDs for scopes (must match the DAP server).
TRACE_PRINT_LN
This event is emitted via trace, and indicates that a line should be printed.

Traits

ProgramExecutor
A transaction-scoped program executor used by TransactionExecutor.

Type Aliases

TraceHandler
A callback to be executed when a TraceEvent occurs