Structs
- DapClient
- A simple DAP protocol client that communicates over TCP.
- DapConfig
- Configuration for the DAP debug server.
- DapExecutor
- A
ProgramExecutorthat starts a DAP TCP server and steps through the program interactively. - DapUi
Frame - A single remote frame within a bundled UI-state snapshot.
- DapUi
State - A bundled snapshot of the remote state needed by the TUI.
- Debug
Executor - A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.
- Debugger
Host - This is an implementation of Host which is essentially miden_processor::DefaultHost, but extended with additional functionality for debugging, in particular it manages trace events that record the entry or exit of a procedure call frame.
- Diagnostic
Executor - A
ProgramExecutorthat wrapsFastProcessorwith diagnostic capabilities. - Execution
Config - Execution
Trace - An ExecutionTrace represents a final state of a program that was executed.
- Executor
- The Executor is responsible for executing a program with the Miden VM.
Enums
- DapStop
Reason - The reason the debuggee stopped after a step/continue command.
- Trace
Event - A typed wrapper around the raw trace events known to the compiler
Constants
- SCOPE_
MEMORY - SCOPE_
STACK - Variables reference IDs for scopes (must match the DAP server).
Traits
- Program
Executor - A transaction-scoped program executor used by
TransactionExecutor.
Type Aliases
- Trace
Handler - A callback to be executed when a TraceEvent occurs at a given clock cycle