DebugExecutor

Struct DebugExecutor 

pub struct DebugExecutor {
Show 14 fields pub processor: FastProcessor, pub host: DebuggerHost<dyn SourceManager>, pub resume_ctx: Option<ResumeContext>, pub current_stack: Vec<Felt>, pub current_op: Option<Operation>, pub current_asmop: Option<AssemblyOp>, pub stack_outputs: StackOutputs, pub contexts: BTreeSet<ContextId>, pub root_context: ContextId, pub current_context: ContextId, pub callstack: CallStack, pub recent: VecDeque<Operation>, pub cycle: usize, pub stopped: bool,
}
A special version of crate::Executor which provides finer-grained control over execution, and captures a ton of information about the program being executed, so as to make it possible to introspect everything about the program and the state of the VM at a given cycle.

This is used by the debugger to execute programs, and provide all of the functionality made available by the TUI.

Fields

processor: FastProcessor

The underlying FastProcessor being driven

host: DebuggerHost<dyn SourceManager>

The host providing debugging callbacks

resume_ctx: Option<ResumeContext>

The resume context for the next step (None if program has finished)

current_stack: Vec<Felt>

The current operand stack state

current_op: Option<Operation>

The operation that was just executed

current_asmop: Option<AssemblyOp>

The assembly-level operation info for the current op

stack_outputs: StackOutputs

The final outcome of the program being executed

contexts: BTreeSet<ContextId>

The set of contexts allocated during execution so far

root_context: ContextId

The root context

current_context: ContextId

The current context at cycle

callstack: CallStack

The current call stack

recent: VecDeque<Operation>

A sliding window of the last 5 operations successfully executed by the VM

cycle: usize

The current clock cycle

stopped: bool

Whether or not execution has terminated

Implementations

Source

impl DebugExecutor

pub fn step(&mut self) -> Result<Option<CallFrame>, ExecutionError>

Advance the program state by one cycle.

If the program has already reached its termination state, it returns the same result as the previous time it was called.

Returns the call frame exited this cycle, if any

pub fn into_execution_trace(self) -> ExecutionTrace

Consume the DebugExecutor, converting it into an ExecutionTrace at the current cycle.