pub struct DebuggerConfig {
pub input: Option<InputFile>,
pub inputs: Option<ExecutionConfig>,
pub args: Vec<Felt>,
pub working_dir: Option<PathBuf>,
pub sysroot: Option<PathBuf>,
pub color: ColorChoice,
pub entrypoint: Option<String>,
pub dap_connect: Option<String>,
pub search_path: Vec<PathBuf>,
pub link_libraries: Vec<LinkLibrary>,
pub repl: bool,
}Expand description
Run a compiled Miden program with the Miden VM
Fields
input: Option<InputFile>Specify the path to a Miden program file to execute.
Miden Assembly programs are emitted by the compiler with a .masp extension.
You may use - as a file name to read a file from stdin.
inputs: Option<ExecutionConfig>Specify the path to a file containing program inputs.
Program inputs are stack and advice provider values which the program can access during execution. The inputs file is a TOML file which describes what the inputs are, or where to source them from.
args: Vec<Felt>Arguments to place on the operand stack before calling the program entrypoint.
Arguments will be pushed on the operand stack in the order of appearance,
Example: -- a b will push a on the stack, then b.
These arguments must be valid field element values expressed in decimal format.
NOTE: These arguments will override any stack values provided via –inputs
working_dir: Option<PathBuf>The working directory for the debugger
By default this will be the working directory the debugger is executed from
sysroot: Option<PathBuf>The path to the root directory of the current Miden toolchain
By default this is assumed to be `$(midenup show home)/toolchains/$(midenup show active-toolchain)
color: ColorChoiceWhether, and how, to color terminal output
entrypoint: Option<String>Specify the function to call as the entrypoint for the program
in the format <module_name>::<function>
dap_connect: Option<String>Connect to a remote DAP debug server instead of running a local program.
Specify the address of the DAP server (e.g. “127.0.0.1:4711”). When this flag is set, the debugger connects to an existing remote session.
search_path: Vec<PathBuf>Specify one or more search paths for link libraries requested via -l
link_libraries: Vec<LinkLibrary>Link compiled projects to the specified library NAME.
The optional KIND can be provided to indicate what type of library it is.
NAME must either be an absolute path (with extension when applicable), or a library namespace (no extension). The former will be used as the path to load the library, without looking for it in the library search paths, while the latter will be located in the search path based on its KIND.
See below for valid KINDs:
repl: boolUse the REPL (text-mode) debugger instead of the TUI
Implementations
Sourceimpl DebuggerConfig
impl DebuggerConfig
pub fn working_dir(&self) -> Cow<'_, Path>
pub fn toolchain_dir(&self) -> Option<PathBuf>