State

Struct State 

pub struct State {
    pub source_manager: Arc<dyn SourceManager>,
    pub config: Box<DebuggerConfig>,
    pub input_mode: InputMode,
    pub breakpoints: Vec<Breakpoint>,
    pub breakpoints_hit: Vec<Breakpoint>,
    pub next_breakpoint_id: u8,
    pub stopped: bool,
    pub debug_mode: DebugMode,
    /* private fields */
}

Fields

source_manager: Arc<dyn SourceManager>config: Box<DebuggerConfig>input_mode: InputModebreakpoints: Vec<Breakpoint>breakpoints_hit: Vec<Breakpoint>next_breakpoint_id: u8stopped: booldebug_mode: DebugMode

Implementations

Source

impl State

pub fn new(config: Box<DebuggerConfig>) -> Result<Self, Report>

pub fn new_for_transaction( program: Arc<Program>, stack_inputs: StackInputs, advice_inputs: AdviceInputs, source_manager: Arc<dyn SourceManager>, mast_forests: Vec<Arc<MastForest>>, event_replay: Vec<Vec<AdviceMutation>>, ) -> Result<Self, Report>

Create a new debugger state for transaction debugging.

This uses pre-recorded event mutations to replay host events during step-by-step debugging, since the debugger’s host doesn’t have access to the real transaction host.

pub fn reload(&mut self) -> Result<(), Report>

pub fn create_breakpoint(&mut self, ty: BreakpointType)

pub fn executor(&self) -> &DebugExecutor

pub fn executor_mut(&mut self) -> &mut DebugExecutor

pub fn execution_failed(&self) -> Option<&ExecutionError>

pub fn set_execution_failed(&mut self, error: ExecutionError)

Source

impl State

pub fn read_memory(&mut self, expr: &ReadMemoryExpr) -> Result<String, String>

Source

impl State

pub fn new_for_dap(addr: &str) -> Result<Self, Report>

Create a new debugger state for remote DAP debugging.

Connects to a DAP server, performs the handshake, and queries the initial state to populate the executor fields that the TUI panes read.

pub fn step_remote(&mut self) -> Result<DapStopReason, Report>